@@ -26,15 +26,16 @@
 
 #include <QStyleOptionGraphicsItem>
 
-class TestQgsLayoutUtils: public QgsTest
+class TestQgsLayoutUtils : public QgsTest
 {
     Q_OBJECT
 
   public:
-    TestQgsLayoutUtils() : QgsTest( QStringLiteral( "Layout Utils Tests" ), QStringLiteral( "composer_utils" ) ) {}
+    TestQgsLayoutUtils()
+      : QgsTest( QStringLiteral( "Layout Utils Tests" ), QStringLiteral( "composer_utils" ) ) {}
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
+    void initTestCase(); // will be called before the first testfunction is executed.
     void cleanupTestCase();
     void rotate();
     void normalizedAngle(); //test normalised angle function
@@ -43,23 +44,22 @@ class TestQgsLayoutUtils: public QgsTest
     void createRenderContextFromMap();
     void relativePosition();
     void relativeResizeRect();
-    void pointsToMM(); //test conversion of point size to mm
-    void mmToPoints(); //test conversion of mm to point size
-    void scaledFontPixelSize(); //test creating a scaled font
-    void fontAscentMM(); //test calculating font ascent in mm
-    void fontDescentMM(); //test calculating font descent in mm
-    void fontHeightMM(); //test calculating font height in mm
+    void pointsToMM();            //test conversion of point size to mm
+    void mmToPoints();            //test conversion of mm to point size
+    void scaledFontPixelSize();   //test creating a scaled font
+    void fontAscentMM();          //test calculating font ascent in mm
+    void fontDescentMM();         //test calculating font descent in mm
+    void fontHeightMM();          //test calculating font height in mm
     void fontHeightCharacterMM(); //test calculating font character height in mm
-    void textWidthMM(); //test calculating text width in mm
-    void textHeightMM(); //test calculating text height in mm
-    void drawTextPos(); //test drawing text at a pos
-    void drawTextRect(); //test drawing text in a rect
-    void largestRotatedRect(); //test largest rotated rect helper function
+    void textWidthMM();           //test calculating text width in mm
+    void textHeightMM();          //test calculating text height in mm
+    void drawTextPos();           //test drawing text at a pos
+    void drawTextRect();          //test drawing text in a rect
+    void largestRotatedRect();    //test largest rotated rect helper function
     void decodePaperOrientation();
     void mapLayerFromString();
 
   private:
-
     QFont mTestFont;
 };
 
@@ -78,7 +78,7 @@ void TestQgsLayoutUtils::cleanupTestCase()
 void TestQgsLayoutUtils::rotate()
 {
   // pairs of lines from before -> expected after position and angle to rotate
-  QList< QPair< QLineF, double > > testVals;
+  QList<QPair<QLineF, double>> testVals;
   testVals << qMakePair( QLineF( 0, 1, 0, 1 ), 0.0 );
   testVals << qMakePair( QLineF( 0, 1, -1, 0 ), 90.0 );
   testVals << qMakePair( QLineF( 0, 1, 0, -1 ), 180.0 );
@@ -86,7 +86,7 @@ void TestQgsLayoutUtils::rotate()
   testVals << qMakePair( QLineF( 0, 1, 0, 1 ), 360.0 );
 
   //test rotate helper function
-  QList< QPair< QLineF, double > >::const_iterator it = testVals.constBegin();
+  QList<QPair<QLineF, double>>::const_iterator it = testVals.constBegin();
   for ( ; it != testVals.constEnd(); ++it )
   {
     double x = ( *it ).first.x1();
@@ -99,7 +99,7 @@ void TestQgsLayoutUtils::rotate()
 
 void TestQgsLayoutUtils::normalizedAngle()
 {
-  QList< QPair< double, double > > testVals;
+  QList<QPair<double, double>> testVals;
   testVals << qMakePair( 0.0, 0.0 );
   testVals << qMakePair( 90.0, 90.0 );
   testVals << qMakePair( 180.0, 180.0 );
@@ -114,18 +114,17 @@ void TestQgsLayoutUtils::normalizedAngle()
   testVals << qMakePair( -760.0, 320.0 );
 
   //test normalized angle helper function
-  QList< QPair< double, double > >::const_iterator it = testVals.constBegin();
+  QList<QPair<double, double>>::const_iterator it = testVals.constBegin();
   for ( ; it != testVals.constEnd(); ++it )
 
   {
     const double result = QgsLayoutUtils::normalizedAngle( ( *it ).first );
     qDebug() << QStringLiteral( "actual: %1 expected: %2" ).arg( result ).arg( ( *it ).second );
     QGSCOMPARENEAR( result, ( *it ).second, 4 * std::numeric_limits<double>::epsilon() );
-
   }
 
   //test with allowing negative angles
-  QList< QPair< double, double > > negativeTestVals;
+  QList<QPair<double, double>> negativeTestVals;
   negativeTestVals << qMakePair( 0.0, 0.0 );
   negativeTestVals << qMakePair( 90.0, 90.0 );
   negativeTestVals << qMakePair( 360.0, 0.0 );
@@ -142,13 +141,12 @@ void TestQgsLayoutUtils::normalizedAngle()
     const double result = QgsLayoutUtils::normalizedAngle( ( *it ).first, true );
     qDebug() << QStringLiteral( "actual: %1 expected: %2" ).arg( result ).arg( ( *it ).second );
     QGSCOMPARENEAR( result, ( *it ).second, 4 * std::numeric_limits<double>::epsilon() );
-
   }
 }
 
 void TestQgsLayoutUtils::snappedAngle()
 {
-  QList< QPair< double, double > > testVals;
+  QList<QPair<double, double>> testVals;
   testVals << qMakePair( 0.0, 0.0 );
   testVals << qMakePair( 10.0, 0.0 );
   testVals << qMakePair( 20.0, 0.0 );
@@ -188,7 +186,7 @@ void TestQgsLayoutUtils::snappedAngle()
   testVals << qMakePair( 360.0, 0.0 );
 
   //test snapped angle helper function
-  QList< QPair< double, double > >::const_iterator it = testVals.constBegin();
+  QList<QPair<double, double>>::const_iterator it = testVals.constBegin();
   for ( ; it != testVals.constEnd(); ++it )
   {
     QGSCOMPARENEAR( QgsLayoutUtils::snappedAngle( ( *it ).first ), ( *it ).second, 4 * std::numeric_limits<double>::epsilon() );
@@ -245,24 +243,28 @@ void TestQgsLayoutUtils::createRenderContextFromLayout()
   QVERIFY( !rc.painter() );
 
   // check render context flags are correctly set
-  l.renderContext().setFlags( QgsLayoutRenderContext::Flags() );
+  l.renderContext().setFlags( Qgis::LayoutRenderFlags() );
   rc = QgsLayoutUtils::createRenderContextForLayout( &l, nullptr );
   QVERIFY( !( rc.flags() & Qgis::RenderContextFlag::Antialiasing ) );
   QVERIFY( !( rc.flags() & Qgis::RenderContextFlag::UseAdvancedEffects ) );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::ForceVectorOutput ) );
 
-  l.renderContext().setFlag( QgsLayoutRenderContext::FlagAntialiasing );
+  l.renderContext().setFlag( Qgis::LayoutRenderFlag::Antialiasing );
   rc = QgsLayoutUtils::createRenderContextForLayout( &l, nullptr );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::Antialiasing ) );
   QVERIFY( !( rc.flags() & Qgis::RenderContextFlag::UseAdvancedEffects ) );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::ForceVectorOutput ) );
 
-  l.renderContext().setFlag( QgsLayoutRenderContext::FlagUseAdvancedEffects );
+  l.renderContext().setFlag( Qgis::LayoutRenderFlag::UseAdvancedEffects );
   rc = QgsLayoutUtils::createRenderContextForLayout( &l, nullptr );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::Antialiasing ) );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::UseAdvancedEffects ) );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::ForceVectorOutput ) );
 
+  l.renderContext().setRasterizedRenderingPolicy( Qgis::RasterizedRenderingPolicy::ForceVector );
+  rc = QgsLayoutUtils::createRenderContextForLayout( &l, nullptr );
+  QCOMPARE( rc.rasterizedRenderingPolicy(), Qgis::RasterizedRenderingPolicy::ForceVector );
+
   // check text format is correctly set
   l.renderContext().setTextRenderFormat( Qgis::TextRenderFormat::AlwaysOutlines );
   rc = QgsLayoutUtils::createRenderContextForLayout( &l, nullptr );
@@ -325,19 +327,19 @@ void TestQgsLayoutUtils::createRenderContextFromMap()
   QVERIFY( rc.painter() );
 
   // check render context flags are correctly set
-  l.renderContext().setFlags( QgsLayoutRenderContext::Flags() );
+  l.renderContext().setFlags( Qgis::LayoutRenderFlags() );
   rc = QgsLayoutUtils::createRenderContextForMap( map2, &p );
   QVERIFY( !( rc.flags() & Qgis::RenderContextFlag::Antialiasing ) );
   QVERIFY( !( rc.flags() & Qgis::RenderContextFlag::UseAdvancedEffects ) );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::ForceVectorOutput ) );
 
-  l.renderContext().setFlag( QgsLayoutRenderContext::FlagAntialiasing );
+  l.renderContext().setFlag( Qgis::LayoutRenderFlag::Antialiasing );
   rc = QgsLayoutUtils::createRenderContextForMap( map2, &p );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::Antialiasing ) );
   QVERIFY( !( rc.flags() & Qgis::RenderContextFlag::UseAdvancedEffects ) );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::ForceVectorOutput ) );
 
-  l.renderContext().setFlag( QgsLayoutRenderContext::FlagUseAdvancedEffects );
+  l.renderContext().setFlag( Qgis::LayoutRenderFlag::UseAdvancedEffects );
   rc = QgsLayoutUtils::createRenderContextForMap( map2, &p );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::Antialiasing ) );
   QVERIFY( ( rc.flags() & Qgis::RenderContextFlag::UseAdvancedEffects ) );
@@ -458,7 +460,6 @@ void TestQgsLayoutUtils::fontHeightCharacterMM()
   QGSCOMPARENEAR( QgsLayoutUtils::fontHeightCharacterMM( mTestFont, QChar( 'a' ) ), 2.4, 0.15 );
   QGSCOMPARENEAR( QgsLayoutUtils::fontHeightCharacterMM( mTestFont, QChar( 'l' ) ), 3.15, 0.16 );
   QGSCOMPARENEAR( QgsLayoutUtils::fontHeightCharacterMM( mTestFont, QChar( 'g' ) ), 3.2, 0.11 );
-
 }
 
 void TestQgsLayoutUtils::textWidthMM()
@@ -466,7 +467,6 @@ void TestQgsLayoutUtils::textWidthMM()
   //platform specific font rendering differences mean this test needs to be very lenient
   mTestFont.setPointSize( 12 );
   QGSCOMPARENEAR( QgsLayoutUtils::textWidthMM( mTestFont, QString( "test string" ) ), 20, 2 );
-
 }
 
 void TestQgsLayoutUtils::textHeightMM()
@@ -477,7 +477,6 @@ void TestQgsLayoutUtils::textHeightMM()
   QGSCOMPARENEAR( QgsLayoutUtils::textHeightMM( mTestFont, QString( "test\nstring" ) ), 8.7, 0.2 );
   QGSCOMPARENEAR( QgsLayoutUtils::textHeightMM( mTestFont, QString( "test\nstring" ), 2 ), 13.5, 0.2 );
   QGSCOMPARENEAR( QgsLayoutUtils::textHeightMM( mTestFont, QString( "test\nstring\nstring" ) ), 13.5, 0.2 );
-
 }
 
 void TestQgsLayoutUtils::drawTextPos()
@@ -586,8 +585,7 @@ void TestQgsLayoutUtils::largestRotatedRect()
     const QRectF rotatedRectBounds = t.mapRect( result );
     //one of the rotated rects dimensions must equal the bounding rectangles dimensions (ie, it has been constrained by one dimension)
     //and the other dimension must be less than or equal to bounds dimension
-    QVERIFY( ( qgsDoubleNear( rotatedRectBounds.width(), bounds.width(), 0.001 ) && ( rotatedRectBounds.height() <= bounds.height() ) )
-             || ( qgsDoubleNear( rotatedRectBounds.height(), bounds.height(), 0.001 ) && ( rotatedRectBounds.width() <= bounds.width() ) ) );
+    QVERIFY( ( qgsDoubleNear( rotatedRectBounds.width(), bounds.width(), 0.001 ) && ( rotatedRectBounds.height() <= bounds.height() ) ) || ( qgsDoubleNear( rotatedRectBounds.height(), bounds.height(), 0.001 ) && ( rotatedRectBounds.width() <= bounds.width() ) ) );
 
     //also verify that aspect ratio of rectangle has not changed
     QGSCOMPARENEAR( result.width() / result.height(), wideRect.width() / wideRect.height(), 4 * std::numeric_limits<double>::epsilon() );
@@ -601,8 +599,7 @@ void TestQgsLayoutUtils::largestRotatedRect()
     const QRectF rotatedRectBounds = t.mapRect( result );
     //one of the rotated rects dimensions must equal the bounding rectangles dimensions (ie, it has been constrained by one dimension)
     //and the other dimension must be less than or equal to bounds dimension
-    QVERIFY( ( qgsDoubleNear( rotatedRectBounds.width(), bounds.width(), 0.001 ) && ( rotatedRectBounds.height() <= bounds.height() ) )
-             || ( qgsDoubleNear( rotatedRectBounds.height(), bounds.height(), 0.001 ) && ( rotatedRectBounds.width() <= bounds.width() ) ) );
+    QVERIFY( ( qgsDoubleNear( rotatedRectBounds.width(), bounds.width(), 0.001 ) && ( rotatedRectBounds.height() <= bounds.height() ) ) || ( qgsDoubleNear( rotatedRectBounds.height(), bounds.height(), 0.001 ) && ( rotatedRectBounds.width() <= bounds.width() ) ) );
 
     //also verify that aspect ratio of rectangle has not changed
     QGSCOMPARENEAR( result.width() / result.height(), highRect.width() / highRect.height(), 4 * std::numeric_limits<double>::epsilon() );
